#
# ovirt-hosted-engine-setup -- ovirt hosted engine setup
# Copyright (C) 2013-2021 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

%global         package_version 2.6.6
%global         ovirt_hosted_engine_setup_templates %{_datadir}/%{name}/templates
%global         ovirt_hosted_engine_setup_scripts %{_datadir}/%{name}/scripts
%global         vdsmhooksdir %{_libexecdir}/vdsm/hooks

%global         python_interpreter %{__python3}
%global         python38_target_version python38
%global         python_target_version python3
%global         python_sitelib %{python3_sitelib}


Summary:        oVirt Hosted Engine setup tool
Name:           ovirt-hosted-engine-setup
Version:        2.6.6
Release:        1%{?release_suffix}%{?dist}
License:        LGPLv2+
URL:            http://www.ovirt.org
Source:         https://github.com/oVirt/%{name}/releases/download/%{name}-%{package_version}/%{name}-%{package_version}.tar.gz
Group:          Applications/System

BuildArch:      noarch

# Python dependencies

Requires:       %{python_target_version}
%if 0%{?rhel} < 9
# On RHEL 9 it uses Python 3.9 platform support.
Requires:       %{python38_target_version}
%endif

Requires:       %{python_target_version}-ethtool >= 0.6-3
Requires:       %{python_target_version}-ovirt-engine-sdk4 >= 4.3.1
Requires:       %{python_target_version}-sanlock
Requires:       %{python_target_version}-libselinux

Requires:       %{python_target_version}-distro
Requires:       %{python_target_version}-netaddr
Requires:       %{python_target_version}-otopi >= 1.9.0
Requires:       %{python_target_version}-ovirt-setup-lib >= 1.3.3
Requires:       %{python_target_version}-six

BuildRequires:  %{python_target_version}-devel
BuildRequires:  %{python_target_version}-pytest
BuildRequires:  gettext-devel

# Non Python dependencies
Requires:       bind-utils
Requires:       lsof
Requires:       openssh-server
Requires:       openssl
Requires:       sanlock >= 2.8
Requires:       sudo
Requires:       libvirt-client >= 6.6.0-9
Requires:       virt-install

Requires:       ansible-core >= 2.12
# ansible-core 2.13 uses Python 3.9, and many modules are missing a Python 3.9
# build on el8. TODO: Provide them? Instead of or in addition to Python 3.8?
%if 0%{?rhel} < 9
Conflicts:      ansible-core >= 2.13
%endif

Requires:       ovirt-ansible-collection >= 2.0.0
# default libvirt network
Requires:       libvirt-daemon-config-network

BuildRequires:  gettext >= 0.18.2
# gcc is needed by gettext
# TODO: figure out how to configure gettext to not require gcc.
BuildRequires:  gcc

%if 0%{?fedora}
Requires:       qemu-img
%endif

%if 0%{?centos}
Requires:       qemu-img
%else
Requires:       qemu-img >= 15:3.1.0-20.module+el8+2888+cdc893a8
%endif


Requires:       ovirt-hosted-engine-ha >= 2.4
Requires:       glusterfs-cli >= 5.6
Requires:       vdsm-python >= 4.50
Requires(post): vdsm-python >= 4.50
Requires:       ovirt-host >= 4.5.0

Conflicts:      ovirt-engine-appliance < 4.5
Conflicts:      ovirt-engine-appliance >= 4.6


%description
Hosted Engine setup tool for oVirt project.

%prep
%setup -q -n %{name}-%{package_version}

%build
%configure \
        --docdir="%{_docdir}/%{name}-%{version}" \
        --disable-python-syntax-check \
        --disable-ansible-syntax-check \
        %{?conf}
make %{?_smp_mflags}

%check
make test

%install
make %{?_smp_mflags} install DESTDIR="%{buildroot}"
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc README.md
%doc readme.appliance
%doc readme.rollback
%dir %{_sysconfdir}/ovirt-hosted-engine-setup.env.d
%dir %{_sysconfdir}/ovirt-hosted-engine
%ghost %attr(600, root, root) %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
%dir %attr(700, root, root) %{_localstatedir}/log/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup/answers
%{_sbindir}/hosted-engine
%{_sbindir}/ovirt-hosted-engine-setup
%{_sbindir}/ovirt-hosted-engine-cleanup
%{python_sitelib}/ovirt_hosted_engine_setup/
%{_datadir}/%{name}/
%{_mandir}/man8/*

#move to a separate package?
%{vdsmhooksdir}/before_vm_start/

%post
touch %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
chmod 600 %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
%{python_interpreter} -c '
from vdsm.tool.configurators import passwd
print((
    "[credentials-vdsm]\n"
    "authname={authname}\n"
    "password={password}\n\n"
    "[auth-libvirt-localhost]\n"
    "credentials=vdsm\n"
).format(
    authname=passwd.SASL_USERNAME,
    password=passwd.libvirt_password(),
))
' > %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf

%changelog
* Thu Oct 27 2022 Lev Veyde <lveyde@redhat.com> - 2.6.6-1
* 2.6.6-1

* Sun Jul 24 2022 Asaf Rachmani <arachman@redhat.com>  - 2.6.6-0.0.master
- 2.6.6-0.0.master

* Sun Jul 24 2022 Asaf Rachmani <arachman@redhat.com> - 2.6.5-1
- 2.6.5-1

* Thu Jun 02 2022 Asaf Rachmani <arachman@redhat.com>  - 2.6.5-0.0.master
- 2.6.5-0.0.master

* Thu Jun 02 2022 Asaf Rachmani <arachman@redhat.com> - 2.6.4-1
- 2.6.4-1

* Tue Mar 29 2022 Asaf Rachmani <arachman@redhat.com>  - 2.6.4-0.0.master
- 2.6.4-0.0.master

* Mon Mar 28 2022 Asaf Rachmani <arachman@redhat.com> - 2.6.3-1
- 2.6.3-1

* Thu Mar 24 2022 Yedidyah Bar David <didi@redhat.com> - 2.6.3-0.0.master
- 2.6.3-0.0.master

* Thu Mar 24 2022 Yedidyah Bar David <didi@redhat.com> - 2.6.2-1
- 2.6.2-1

* Tue Jan 25 2022 Asaf Rachmani <arachman@redhat.com> - 2.6.2-0.0.master
- 2.6.2-0.0.master

* Mon Jan 24 2022 Asaf Rachmani <arachman@redhat.com> - 2.6.1-1
- 2.6.1-1

* Wed Nov 17 2021 Asaf Rachmani <arachman@redhat.com> - 2.6.1-0.0.master
- 2.6.1-0.0.master

* Wed Nov 17 2021 Asaf Rachmani <arachman@redhat.com> - 2.6.0-1
- 2.6.0-1
